/*
 * Copyright (C) 2003 Dominik Seichter <domseichter@web.de>
 */

#include "kesi.h"
#include "csvimportdlg.h"

#include <qgroupbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qsqldatabase.h>

#include <kapplication.h>
#include <kconfig.h>
#include <kcombobox.h>
#include <klocale.h>
#include <klineedit.h>
#include <kmessagebox.h>

KESI::KESI( QWidget* parent, const char* name )
    : KDialogBase( KDialogBase::Plain, i18n("Database Settings"),
      KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, parent,name)
{
    QVBoxLayout* layout = new QVBoxLayout( plainPage(), 6, 6 );

    QGroupBox* groupDatabase = new QGroupBox( plainPage() );
    groupDatabase->setTitle( i18n( "Database Settings" ) );
    groupDatabase->setColumnLayout(0, Qt::Vertical );
    groupDatabase->layout()->setSpacing( 6 );
    groupDatabase->layout()->setMargin( 11 );
    QVBoxLayout* groupDatabaseLayout = new QVBoxLayout( groupDatabase->layout());
    groupDatabaseLayout->setAlignment( Qt::AlignTop );

    QGridLayout* grid = new QGridLayout( 2, 2 );
    QLabel* label = new QLabel( groupDatabase );
    label->setText( i18n("Username :") );
    grid->addWidget( label, 0, 0 );

    m_username = new KLineEdit( groupDatabase );
    grid->addWidget( m_username, 0, 1 );

    label = new QLabel( groupDatabase );
    label->setText( i18n("Password :") );
    grid->addWidget( label, 1, 0 );

    m_password = new KLineEdit( groupDatabase );
    m_password->setEchoMode( KLineEdit::Password );
    grid->addWidget( m_password, 1, 1 );

    label = new QLabel( groupDatabase );
    label->setText( i18n("Database :") );
    grid->addWidget( label, 2, 0 );

    m_database = new KLineEdit( "kbarcode", groupDatabase );
    grid->addWidget( m_database, 2, 1 );

    label = new QLabel( groupDatabase );
    label->setText( i18n("Host :") );
    grid->addWidget( label, 3, 0 );

    m_hostname = new KLineEdit( "localhost", groupDatabase );
    grid->addWidget( m_hostname, 3, 1 );

    label = new QLabel( groupDatabase );
    label->setText( i18n("Driver :") );
    grid->addWidget( label, 4, 0 );

    m_driver = new KComboBox( false, groupDatabase );
    QStringList drList = QSqlDatabase::drivers();
    QStringList::Iterator it = drList.begin();
    while( it != drList.end() ) {
        m_driver->insertItem( *it );
        ++it;
    }
    grid->addWidget( m_driver, 4, 1 );
    groupDatabaseLayout->addLayout( grid );

    layout->addWidget( groupDatabase );

    loadConfig();
}

KESI::~KESI()
{
}

void KESI::accept()
{
    QSqlDatabase* db = QSqlDatabase::addDatabase( m_driver->currentText() );

    db->setDatabaseName( m_database->text() );
    db->setUserName( m_username->text() );
    db->setPassword( m_password->text() );
    db->setHostName( m_hostname->text() );

    if( !db->open() ) {
        KMessageBox::error( 0, i18n("<qt>Connection failed:<br>") + m_database->text() + "<br>" +
              db->lastError().databaseText() + "</qt>" );
        QSqlDatabase::removeDatabase( m_database->text() );
        return;
    } else {
        saveConfig();

        CSVImportDlg* dlg = new CSVImportDlg( db );
        kapp->setMainWidget( dlg );
        dlg->show();

        KDialogBase::accept();
    }
}

void KESI::loadConfig()
{
    KConfig* config = kapp->config();

    m_database->setText( config->readEntry("database", "") );
    m_username->setText( config->readEntry("username", "") );
    m_password->setText( config->readEntry("password", "") );
    m_hostname->setText( config->readEntry("hostname", "localhost") );
    m_driver->setCurrentItem( config->readNumEntry("driver", 0) );
}

void KESI::saveConfig()
{
    KConfig* config = kapp->config();

    config->writeEntry( "database", m_database->text() );
    config->writeEntry( "username", m_username->text() );
    config->writeEntry( "password", m_password->text() );
    config->writeEntry( "hostname", m_hostname->text() );
    config->writeEntry( "driver", m_driver->currentItem() );
}

#include "kesi.moc"
